require File.expand_path(File.dirname(__FILE__) + '/spec_helper')


describe "Newsletter7Api" do

  describe "Newsletter7ApiResource" do

    it "should set site" do
      expect(Newsletter7ApiResource.site.to_s).to eq('http://localhost:3000/api/v1')
    end

    it "should set user" do
      expect(Newsletter7ApiResource.user).to eq('newsletter7')
    end

    it "should set password" do
      expect(Newsletter7ApiResource.password).to eq('defaultpw')
    end
  end

  describe "ContactGroup" do

    before do
      @contact_groups  = [{ name: 'Bonofa Group', description: 'test' }].to_json
      @contact_group = { name: 'Bonofa Group', contacts: [{first_name: 'first_name', last_name: 'last_name', email: 'test@test.com'}] }.to_json

      ActiveResource::HttpMock.respond_to do |mock|
        mock.get    "/api/v1/contact_groups.json", {"Authorization"=>"Basic bmV3c2xldHRlcjc6ZGVmYXVsdHB3", "Accept"=>"application/json"}, @contact_groups
        mock.post   "/api/v1/contact_groups.json", {"Authorization"=>"Basic bmV3c2xldHRlcjc6ZGVmYXVsdHB3", "Content-Type"=>"application/json"}, @contact_group, 201
      end
    end

    it "should fetch contact groups" do
      contact_groups = Newsletter7Api::ContactGroup.all
      expect(contact_groups).to be_a(ActiveResource::Collection)
    end

    it "should save contacts" do
      contact_group = Newsletter7Api::ContactGroup.new({name: 'Bonofa Group', contacts: [{first_name: 'first_name', last_name: 'last_name', email: 'test@test.com'}]})
      contact_group.save
      expect(contact_group.name).to eq('Bonofa Group')
    end
  end

  describe "Controller" do

    describe "before filter" do

      it "should generate access token in header" do
        expect(Newsletter7ApiResource.connection.set_header('ACCESS_TOKEN', 'promotion_code')).to eq({"ACCESS_TOKEN"=>"#{Base64.encode64(Encryptor.encrypt(value: 'promotion_code', key: 'defaultpw'))}"})
      end
    end
  end
end
